==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-taskbar/taskbar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="641"/>
        <source>Activate task %1</source>
        <translation>Aktywuj zadanie %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
        <source>&amp;Restore</source>
        <translation>P&amp;rzywróć</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Zamknij grupę</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Ustawienia menedżera zadań LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Zawartość listy okien</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Ustawienia menedżera zadan</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Pokazuj tylko okna pulpitu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>&amp;Pokazuj tylko okna z ekranu z tym panelem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Pokazuj tylko zminimalizowane okna</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Unoś zminimalizowane okna na obecnym pulpicie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Zmieniaj stan okien rolką myszy</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Grupowanie okien</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Pokazuj podgląd przy przyłożeniu kursora</translation>
    </message>
    <message>
        <source>Show popup on mouse hover </source>
        <translation type="vanished">Pokazuj podgląd przy przyłożeniu kursora </translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Maksymalna szerokość przycisku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Maksymalna wysokość przycisku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Używaj ikon z WindowClass, jeśli dostępne</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatycznie ob&amp;racaj przyciski, jeżeli panel jest pionowy</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Wygląd listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maksymalna szerokość</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Zamknij środkowym klawiszem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>Obecny</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-taskbar/taskbar_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation>Aktywuj zadanie %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>Na &amp;pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>Pulpit &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Na obecny pulpit</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation>&amp;Przenieś</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Zmień rozmiar</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>Zma&amp;ksymalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>Zmaksymalizuj pionowo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>Zmaksymalizuj poziomo</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>P&amp;rzywróć</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>Zmi&amp;nimalizuj</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>&amp;Warstwa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>Zawsze na &amp;wierzchu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalnie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>Zawsze pod &amp;spodem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Zamknij grupę</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Ustawienia menedżera zadań LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Zawartość listy okien</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Ustawienia menedżera zadan</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Pokazuj tylko okna pulpitu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>&amp;Pokazuj tylko okna z ekranu z tym panelem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Pokazuj tylko zminimalizowane okna</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Unoś zminimalizowane okna na obecnym pulpicie</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Zmieniaj stan okien rolką myszy</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Grupowanie okien</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Pokazuj podgląd przy przyłożeniu kursora</translation>
    </message>
    <message>
        <source>Show popup on mouse hover </source>
        <translation type="vanished">Pokazuj podgląd przy przyłożeniu kursora </translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Maksymalna szerokość przycisku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Maksymalna wysokość przycisku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Używaj ikon z WindowClass, jeśli dostępne</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Pokazuj okna z obecnego pulpitu</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Pokazuj okna ze wszystkich pulpitów</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatycznie ob&amp;racaj przyciski, jeżeli panel jest pionowy</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Wygląd listy zadań</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Styl przycisku</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maksymalna szerokość</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Zamknij środkowym klawiszem</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Ikona i tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Tylko ikona</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Tylko tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>Obecny</translation>
    </message>
</context>
</TS>
